import { Separator } from "./Separator";
import { AuthorData } from "./table";
import { cn } from "./util/cn";

interface CommentDataBase {
    id: number;
    author: AuthorData;
    text: string;
    timestamp: string;
    showDelete?: boolean;
}
export interface SubCommentData extends CommentDataBase {
    parentId?: number;
}
export interface CommentData extends CommentDataBase {
    subComments?: SubCommentData[]; // Optional sub-comments
}

export function CommentListContainer({
    children,
}: {
    children: React.ReactNode;
}) {
    return <ul className="list-none pl-0 m-0 text-[13px]">{children}</ul>
}
export function CommentItem({ comment }: { comment: CommentData }) {
    const renderSubComments = () => {
        if (comment.subComments && comment.subComments.length > 0) {
            return (
                <CommentReplySection comments={comment.subComments} />
            );
        }
        return null; // No sub-comments to render
    }
    return <>
        <li className="bg-transparent text-[13px]">
            <div className="border-t relative border-custom-gray-light px-[3px] pt-[9px] pb-[7px] flex"
            >
                <div style={{
                    width: '132px', marginRight: '33px', marginTop: '3px',
                    lineHeight: '13px'
                }}>
                    <span className="relative text-[13px] cursor-pointer inline">
                        <span style={{
                            fontSize: '12px',
                            color: 'rgb(119, 119, 119)',
                            verticalAlign: 'top'
                        }}
                            className="font-normal"
                        >
                            <em
                                className="overflow-hidden text-ellipsis not-italic
                            align-tops pr-px inline-block text-nowrap max-w-[110px]"
                            > {comment.author.type === 'nickname' ? comment.author.nickname : 'ㅇㅇ'} </em>
                        </span>
                        {comment.author.type === 'nickname' && (
                            <a className="text-custom-gray-dark inline">
                                <img
                                    className="inline-block align-middle cursor-pointer"
                                    src="/fix_nik.gif" alt="icon"
                                />
                            </a>
                        )}
                    </span>
                </div>
                <div style={{
                    width: '820px', cursor: 'pointer'
                }}
                    className="flex-1"
                >
                    <p style={{
                        lineHeight: '20px', cursor: 'pointer',
                        wordBreak: 'break-all',
                        overflowX: 'hidden', overflowY: 'hidden', width: '820px'
                    }}
                        className="overflow-hidden break-all cursor-pointer"
                    > {comment.text} </p>
                </div>
                <div className="flex items-center justify-between">
                    <span className="text-custom-gray-medium align-middle mt-px text-[12px] float-left">
                        {comment.timestamp}
                    </span>
                    {comment.showDelete && (
                        <div className="flex items-center justify-end ml-[6px] relative">
                            <button className="
                        bg-sp-img bg-[-268px_-200px] w-[13px] h-[13px]
                        align-top font-apple-dotum
                        " />
                        </div>
                    )}
                </div>
            </div>
        </li>
        {renderSubComments()}
    </>
}

function CommentReplyItem({ comment }: { comment: SubCommentData }) {
    // Function to handle potential HTML in author name
    const renderAuthor = () => {
        const authorMaxWidth = comment.author.type === 'IP' ? '84px' : '107px'; // Default to 107px if not specified
        return (
            <em
                className="inline-block text-ellipsis overflow-hidden whitespace-nowrap align-top not-italic text-custom-gray-dark"
                style={{ maxWidth: authorMaxWidth }} // Apply dynamic max-width
            >
                {comment.author.type === 'nickname' ? comment.author.nickname : 'ㅇㅇ'}
            </em>
        );
    };

    return (
        <li className="bg-transparent pt-[9px] pr-3 pb-[7px] pl-3 border-t border-solid border-gray-300 first:border-t-0">
            <div className="bg-transparent relative flow-root"> {/* Use flow-root to contain floats */}
                {/* Author Info */}
                <div className="bg-transparent float-left w-[133px] mr-[23px] mt-[3px] leading-[13px]">
                    <span className="bg-transparent relative text-[13px] cursor-pointer">
                        <span className="bg-transparent text-xs text-gray-700 align-top">
                            {renderAuthor()}
                            {comment.author.type === "IP" && ( // Conditionally render IP if it exists
                                <span className="bg-transparent font-tahoma text-[11px] text-custom-gray-medium inline-block align-[1px] ml-1">
                                    ({comment.author.ip})
                                </span>
                            )}
                            {comment.author.type === "nickname" && (
                                <a
                                    className="text-custom-gray-dark inline ml-1"
                                > <img
                                        className="inline-block align-middle cursor-pointer"
                                        src={
                                            comment.author.userType === "manager" ? "/fix_managernik.gif" :
                                                comment.author.userType === "submanager" ? "/fix_sub_managernik.gif" :
                                                    "/fix_nik.gif"} alt="icon"
                                    />
                                </a>
                            )}
                        </span>
                    </span>
                </div>

                {/* Timestamp and Actions (float right first in source order for correct float behavior) */}
                <div className="bg-transparent float-right">
                    <span className="bg-transparent float-left text-xs text-custom-gray-medium align-top mt-[1px] mr-2">
                        {comment.timestamp}
                    </span>
                    {comment.showDelete && ( // Conditionally render delete button
                        <div className="bg-transparent float-right relative top-[3px] right-0">
                            {/* Using top-[3px] might need adjustment based on exact alignment needs */}
                            <button
                                title="삭제" // Add title for accessibility
                                className="bg-transparent cursor-pointer align-top text-[0px] font-apple-dotum text-custom-gray-medium bg-sp-img bg-[-268px_-200px] leading-none w-[13px] h-[13px]"
                            >
                                삭제 {/* Text hidden by text-[0px] but good for screen readers */}
                            </button>
                        </div>
                    )}
                </div>

                {/* Comment Text */}
                {/* Note: Original has width 820px container and 774px text. Simulating this might require careful flex/grid or removing float here */}
                {/* Simplified approach: Let text flow, adjust margins if needed */}
                <div className="bg-transparent overflow-hidden cursor-default"> {/* Use overflow-hidden to contain the text after floats */}
                    <p className="leading-5 cursor-default break-words pl-0">
                        {/* Removed float, width, relative, padding-left: 16px from original P. Adjust if layout breaks */}
                        {/* Original P had pl-16px (pl-4). Let's add it back relative to the start of this div */}
                        <span className="inline-block pl-4">{comment.text}</span> {/* Wrapped text in span to apply padding */}
                    </p>
                </div>

            </div>
        </li>
    );
}

export function CommentReplySection({ comments }: { comments: SubCommentData[] }) {
    return (
        <div className="bg-transparent overflow-hidden h-full text-[13px]"> {/* Assuming full height needed */}
            <div className="bg-gray-50 mb-3 ml-[30px] border border-solid border-gray-300">
                <ul className="bg-transparent list-none">
                    {comments.map((comment) => (
                        <CommentReplyItem key={comment.id} comment={comment} />
                    ))}
                </ul>
            </div>
        </div>
    );
}

// Define the props the component will accept
interface CommentPaginationProps {
    currentPage: number;
    maxPage: number;
    onPageChange?: (page: number) => void; // Optional callback for page changes
    onViewContent?: () => void; // Optional click handler for "본문 보기"
    onCloseComments?: () => void; // Optional click handler for "댓글닫기"
    onRefresh?: () => void; // Optional click handler for "새로고침"
}

export const CommentPagination: React.FC<CommentPaginationProps> = ({
    currentPage,
    maxPage,
    onViewContent,
    onCloseComments,
    onRefresh,
}) => {
    const pageNumbers = Array.from({ length: maxPage }, (_, i) => i + 1); // Generate page numbers

    return (
        <div className="relative mt-[18px] text-center leading-[20px] border-t border-t-custom-gray-light text-[0px] h-[69px] font-apple-dotum">
            {/* Page Number Section */}
            {/* pt/pb values approximate vertical centering within the 69px height */}
            {/* text-center on parent handles horizontal centering */}
            <div className="pt-[23px] pb-[28px]">
                {pageNumbers.map((page) => (
                    <em className={cn("inline-block ml-[9px] text-[14px] font-bold not-italic",
                        currentPage === page && "underline text-custom-red-text"
                    )}>
                        {page}
                    </em>
                ))}
                {/* Add other page numbers logic here if needed */}
            </div>

            {/* Buttons Section */}
            <div className="absolute right-0 top-0 mt-[23px] text-[0px] flex items-center">
                <a
                    href="#view-content" // Use a more appropriate href or make it a button if it triggers an action
                    onClick={(e) => {
                        if (onViewContent) {
                            e.preventDefault(); // Prevent default anchor behavior if it's an action
                            onViewContent();
                        }
                        // Allow default behavior if onViewContent is not provided and href is meaningful
                    }}
                    className="text-custom-gray-dark align-middle leading-[15px] inline-block text-[13px] font-bold font-apple no-underline hover:underline cursor-pointer"
                >
                    본문 보기
                </a>
                <Separator className='mx-2.5' />
                <button
                    type="button"
                    onClick={onCloseComments}
                    className="bg-transparent cursor-pointer align-middle text-[13px] font-apple text-custom-gray-dark font-bold" // Added margin consistency
                >
                    <span className="inline-block text-[13px] font-bold font-apple text-custom-gray-dark"> {/* Removed redundant ml-9, parent button has it */}
                        댓글닫기
                    </span>
                    {/* The @utility bg-sp-img needs to be correctly processed by your CSS build tool */}
                    <em className="bg-sp-img bg-[-84px_-52px] inline-block w-[9px] h-[5px] ml-[4px] align-[2px]">
                        {/* Empty em for background image icon */}
                    </em>
                </button>
                <Separator className='mx-2.5' />
                <button
                    type="button"
                    onClick={onRefresh}
                    className="bg-transparent cursor-pointer align-middle text-[13px] font-apple text-custom-gray-dark font-bold" // Added margin consistency
                >
                    새로고침
                </button>
            </div>
        </div>
    );
};